        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
}
