        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 28 <strong>control</strong><br>0,2,4,6,10,11,15,16,17,18,19,20,22,25,26,29,31,32,33,34,35,36,39,41,45,47,48,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260615 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 23 <br>1,3,5,7,8,9,12,13,14,21,23,24,27,28,30,37,38,40,42,43,44,46,50';}
}
